/**
 * PM - clap switch
 *
 * @authors Adrian Bosilca
 * Copyright (C) 2011, Adrian Bosilca
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <avr/io.h>
#define F_CPU 16000000
#include <util/delay.h>

#define SET_ADC_CH(ch) {	\
	ADMUX&=0b11111000;		\
	ADMUX|=((ch)&7);		\
	}
	
void InitADC(){
	
	PORTA=0;
	ADMUX=(1<<REFS0);// For Aref=AVcc;
	ADCSRA=(1<<ADEN) | (1<<ADPS1)| (1<<ADPS0) | (0<<ADPS2); //Prescalar div factor =128
}

uint16_t ReadADC(){
	//Start Single conversion
	ADCSRA|=(1<<ADSC);
	//Wait for conversion to complete
	while(!(ADCSRA & (1<<ADIF)));

   //Clear ADIF by writing one to it
   //This is standard way of clearing bits in io as said in datasheets.
   //The code writes '1' but it result in setting bit to '0' !!!

	ADCSRA|=(1<<ADIF);

	return(ADC);
}


int main(){
	
	// setam toti pinii portului C ca pini de iesire
	DDRC = 0xFF;
	
	InitADC();
	PORTC = 0;
	
	int val = 0;
	
	SET_ADC_CH(PA7);
	
	while(1){
		if (ReadADC() > 880)	//daca se bate din palme
		{
			if ((PORTC & 7) != 7)	//daca nu sunt aprinse toate LED-urile
			{
				switch (val)
				{
				case 0: 
					PORTC |= 1;		//aprind un LED
					break;
				case 1: 
					PORTC |= 3;		//aprind doua LED-uri
					break;
				case 2: 
					PORTC |= 7;		//aprind trei LED-uri
					break;
				}
				
				val = (val + 1) % 3;
			}
			else	// daca sunt aprinse toate LED-urile
			{
				PORTC = 0;
			}
			_delay_ms(150);
		}
	}
	return 0;
}
